Mode

Enum Mode 

pub enum Mode {
    Byob {
        reader: ReadableStreamByobReader,
        internal_buf: Option<ArrayBuffer>,
    },
    Default {
        reader: ReadableStreamDefaultReader,
    },
}
The underlying stream reader.

A BYOB reader is used when the stream is a byte stream; a default reader is the fallback for the streams that do not support BYOB reads.

Variants



Byob

A BYOB reader; reads into the owned internal buffer.

Fields

reader: ReadableStreamByobReader

The reader itself.

internal_buf: Option<ArrayBuffer>

The owned buffer to pass to the reads.

None when the buffer ownership is currently transferred to a pending read, or when the buffer has not been allocated yet.



Default

A default reader; yields stream-allocated chunks.

Fields

reader: ReadableStreamDefaultReader

The reader itself.

Implementations

Source

impl Mode

pub fn release_lock(&self)

Release the stream lock held by the reader.

pub fn cancel_with_reason(&self, reason: &JsValue) -> Promise

Cancel the stream with the given reason.

pub fn closed(&self) -> Promise

A promise that settles when the stream closes or errors.