pub enum ReadError {
Read(JsValue),
ByobReadConsumedBuffer,
}Expand description
An error that can occur when reading via Reader::read_into.
Variants
Read(JsValue)
The underlying read operation threw an error.
ByobReadConsumedBuffer
A BYOB read consumed the buffer and did not provide a new one; this indicates an error condition.